>From 34d35be66fba01ebcdd11556ab40d6a930230b01 Mon Sep 17 00:00:00 2001
From: Adrien Grand <jpountz@videolan.org>
Date: Sun, 20 Jul 2008 13:53:41 +0200
Subject: [PATCH] Java bindings: Add VOD support.

---
 .../core/src/main/java/org/videolan/jvlc/VLM.java  |   24 ++++-
 .../java/org/videolan/jvlc/internal/LibVlc.java    |    7 +-
 .../src/test/java/org/videolan/jvlc/VLMTest.java   |  124 +++++++++++++++++---
 bindings/java/core/src/test/resources/sample.avi   |  Bin 0 -> 7112 bytes
 4 files changed, 135 insertions(+), 20 deletions(-)
 create mode 100644 bindings/java/core/src/test/resources/sample.avi

diff --git a/bindings/java/core/src/main/java/org/videolan/jvlc/VLM.java b/bindings/java/core/src/main/java/org/videolan/jvlc/VLM.java
index 7763726..36cde32 100644
--- a/bindings/java/core/src/main/java/org/videolan/jvlc/VLM.java
+++ b/bindings/java/core/src/main/java/org/videolan/jvlc/VLM.java
@@ -32,7 +32,7 @@ public class VLM
 {
 
     private JVLC jvlc;
-    
+
     private volatile boolean released;
 
     public VLM(JVLC jvlc)
@@ -55,6 +55,20 @@ public class VLM
             exception);
     }
 
+    public void addVod(String name, String input, String[] options, boolean enabled, String muxer)
+    {
+        libvlc_exception_t exception = new libvlc_exception_t();
+        jvlc.getLibvlc().libvlc_vlm_add_vod(
+            jvlc.getInstance(),
+            name,
+            input,
+            options == null ? 0 : options.length,
+            options,
+            enabled ? 1 : 0,
+            muxer,
+            exception);
+    }
+
     public void deleteMedia(String name)
     {
         libvlc_exception_t exception = new libvlc_exception_t();
@@ -91,6 +105,12 @@ public class VLM
         jvlc.getLibvlc().libvlc_vlm_add_input(jvlc.getInstance(), name, input, exception);
     }
 
+    public void setMux(String name, String muxer)
+    {
+        libvlc_exception_t exception = new libvlc_exception_t();
+        jvlc.getLibvlc().libvlc_vlm_set_mux(jvlc.getInstance(), name, muxer, exception);
+    }
+
     public void setMediaLoop(String media, boolean loop)
     {
         libvlc_exception_t exception = new libvlc_exception_t();
@@ -165,7 +185,5 @@ public class VLM
         release();
         super.finalize();
     }
-    
-    
 
 }
diff --git a/bindings/java/core/src/main/java/org/videolan/jvlc/internal/LibVlc.java b/bindings/java/core/src/main/java/org/videolan/jvlc/internal/LibVlc.java
index e4add27..c05d7d8 100644
--- a/bindings/java/core/src/main/java/org/videolan/jvlc/internal/LibVlc.java
+++ b/bindings/java/core/src/main/java/org/videolan/jvlc/internal/LibVlc.java
@@ -510,6 +510,9 @@ public interface LibVlc extends Library
     void libvlc_vlm_add_broadcast(LibVlcInstance p_instance, String psz_name, String psz_input, String psz_output,
         int i_options, String[] ppsz_options, int b_enabled, int b_loop, libvlc_exception_t p_e);
 
+    void libvlc_vlm_add_vod(LibVlcInstance p_instance, String psz_name, String psz_input, int i_options,
+        String[] ppsz_options, int b_enabled, String psz_mux, libvlc_exception_t p_e);
+
     void libvlc_vlm_del_media(LibVlcInstance p_instance, String psz_name, libvlc_exception_t p_e);
 
     void libvlc_vlm_set_enabled(LibVlcInstance p_instance, String psz_name, int b_enabled, libvlc_exception_t p_e);
@@ -522,6 +525,8 @@ public interface LibVlc extends Library
 
     void libvlc_vlm_set_loop(LibVlcInstance p_instance, String psz_name, int b_loop, libvlc_exception_t p_e);
 
+    void libvlc_vlm_set_mux(LibVlcInstance p_instance, String psz_name, String psz_mux, libvlc_exception_t p_e);
+
     void libvlc_vlm_change_media(LibVlcInstance p_instance, String psz_name, String psz_input, String psz_output,
         int i_options, String[] ppsz_options, int b_enabled, int b_loop, libvlc_exception_t p_e);
 
@@ -536,7 +541,7 @@ public interface LibVlc extends Library
     String libvlc_vlm_show_media(LibVlcInstance p_instance, String psz_name, libvlc_exception_t p_e);
 
     void libvlc_vlm_release(LibVlcInstance p_instance, libvlc_exception_t p_e);
-    
+
     // event manager
 
     public static interface LibVlcCallback extends Callback
diff --git a/bindings/java/core/src/test/java/org/videolan/jvlc/VLMTest.java b/bindings/java/core/src/test/java/org/videolan/jvlc/VLMTest.java
index c3938ae..0ea38f1 100644
--- a/bindings/java/core/src/test/java/org/videolan/jvlc/VLMTest.java
+++ b/bindings/java/core/src/test/java/org/videolan/jvlc/VLMTest.java
@@ -36,14 +36,14 @@ public class VLMTest
 {
     private JVLC jvlc;
     
-    private String mrl = getClass().getResource("/raffa_voice.ogg").getFile();
+    private String mrl = getClass().getResource("/sample.avi").getFile();
     
     private String mediaName = "test";
     
     @Before
     public void setup()
     {
-        jvlc = new JVLC("-I dummy --aout=dummy --vout=dummy");
+        jvlc = new JVLC("-I dummy --aout=dummy --vout=dummy --rtsp-host 127.0.0.1:5554");
         jvlc.setLogVerbosity(LoggerVerbosityLevel.INFO);
     }
 
@@ -66,9 +66,16 @@ public class VLMTest
         VLM vlm = jvlc.getVLM();
         vlm.addBroadcast(mediaName, "file://" + mrl, "", null, true, false);
     }
+
+    @Test
+    public void testAddVod()
+    {
+        VLM vlm = jvlc.getVLM();
+        vlm.addVod(mediaName, "file://" + mrl, null, true, null);
+    }
     
     @Test
-    public void testShowMedia()
+    public void testShowBroadcastMedia()
     {
         VLM vlm = jvlc.getVLM();
         vlm.addBroadcast(mediaName, "file://" + mrl, "", null, true, false);
@@ -76,23 +83,49 @@ public class VLMTest
     }
     
     @Test
-    public void testDisableMedia()
+    public void testShowVodMedia()
+    {
+        VLM vlm = jvlc.getVLM();
+        vlm.addVod(mediaName, "file://" + mrl, null, true, null);
+        vlm.showMedia(mediaName);
+    }
+
+    @Test
+    public void testDisableBroadcastMedia()
     {
         VLM vlm = jvlc.getVLM();
         vlm.addBroadcast(mediaName, "file://" + mrl, "", null, true, false);
         vlm.disableMedia(mediaName);
     }
-    
+
+    @Test
+    public void testDisableVodMedia()
+    {
+        VLM vlm = jvlc.getVLM();
+        vlm.addVod(mediaName, "file://" + mrl, null, true, null);
+        vlm.disableMedia(mediaName);
+    }
+
+
     @Test
-    public void testPlayMedia()
+    public void testPlayBroadcastMedia()
     {
         VLM vlm = jvlc.getVLM();
         vlm.addBroadcast(mediaName, "file://" + mrl, "", null, true, false);
         vlm.playMedia(mediaName);
     }
-    
+
+    @Test
+    public void testPlayVodMedia()
+    {
+        VLM vlm = jvlc.getVLM();
+        vlm.addVod(mediaName, "file://" + mrl, null, true, null);
+        vlm.playMedia(mediaName);
+    }
+
+
     @Test
-    public void testPauseMedia()
+    public void testPauseBroadcastMedia()
     {
         VLM vlm = jvlc.getVLM();
         vlm.addBroadcast(mediaName, "file://" + mrl, "", null, true, false);
@@ -101,7 +134,16 @@ public class VLMTest
     }
 
     @Test
-    public void testStopMedia()
+    public void testPauseVodMedia()
+    {
+        VLM vlm = jvlc.getVLM();
+        vlm.addVod(mediaName, "file://" + mrl, null, true, null);
+        vlm.playMedia(mediaName);
+        vlm.pauseMedia(mediaName);
+    }
+
+    @Test
+    public void testStopBroadcastMedia()
     {
         VLM vlm = jvlc.getVLM();
         vlm.addBroadcast(mediaName, "file://" + mrl, "", null, true, false);
@@ -110,38 +152,81 @@ public class VLMTest
     }
 
     @Test
-    public void testSeekMedia()
+    public void testStopVodMedia()
+    {
+        VLM vlm = jvlc.getVLM();
+        vlm.addVod(mediaName, "file://" + mrl, null, true, null);
+        vlm.playMedia(mediaName);
+        vlm.stopMedia(mediaName);
+    }
+
+
+    @Test
+    public void testSeekBroadcastMedia()
     {
         VLM vlm = jvlc.getVLM();
         vlm.addBroadcast(mediaName, "file://" + mrl, "", null, true, false);
         vlm.playMedia(mediaName);
         vlm.seekMedia(mediaName, 0.3f);
     }
-    
+
+    @Test
+    public void testSeekVodMedia()
+    {
+        VLM vlm = jvlc.getVLM();
+        vlm.addVod(mediaName, "file://" + mrl, null, true, null);
+        vlm.playMedia(mediaName);
+        vlm.seekMedia(mediaName, 0.3f);
+    }
+
     @Test
-    public void testAddMediaInput()
+    public void testAddMediaInputToBroadcast()
     {
         VLM vlm = jvlc.getVLM();
         vlm.addBroadcast(mediaName, "file://" + mrl, "", null, true, false);
         vlm.addMediaInput(mediaName, "file://" + mrl);
     }
-    
+
     @Test
-    public void testEnableMedia()
+    public void testAddMediaInputToVod()
+    {
+        VLM vlm = jvlc.getVLM();
+        vlm.addVod(mediaName, "file://" + mrl, null, true, null);
+        vlm.addMediaInput(mediaName, "file://" + mrl);
+    }
+
+    @Test
+    public void testEnableBroadcastMedia()
     {
         VLM vlm = jvlc.getVLM();
         vlm.addBroadcast(mediaName, "file://" + mrl, "", null, false, false);
         vlm.enableMedia(mediaName);
     }
+
+    @Test
+    public void testEnableVodMedia()
+    {
+        VLM vlm = jvlc.getVLM();
+        vlm.addVod(mediaName, "file://" + mrl, null, true, null);
+        vlm.enableMedia(mediaName);
+    }
     
     @Test
-    public void testDeleteMedia()
+    public void testDeleteBroadcastMedia()
     {
         VLM vlm = jvlc.getVLM();
         vlm.addBroadcast(mediaName, "file://" + mrl, "", null, false, false);
         vlm.deleteMedia(mediaName);
     }
-    
+
+    @Test
+    public void testDeleteVodMedia()
+    {
+        VLM vlm = jvlc.getVLM();
+        vlm.addVod(mediaName, "file://" + mrl, null, true, null);
+        vlm.deleteMedia(mediaName);
+    }
+
     @Test
     public void testMediaLoop()
     {
@@ -149,4 +234,11 @@ public class VLMTest
         vlm.addBroadcast(mediaName, "file://" + mrl, "", null, false, false);
         vlm.setMediaLoop(mediaName, true);
     }
+
+    @Test
+    public void testSetMux() {
+        VLM vlm = jvlc.getVLM();
+        vlm.addVod(mediaName, "file://" + mrl, null, true, null);
+        vlm.setMux(mediaName, "ts");
+    }
 }
diff --git a/bindings/java/core/src/test/resources/sample.avi b/bindings/java/core/src/test/resources/sample.avi
new file mode 100644
index 0000000000000000000000000000000000000000..b8b6d795070cd16b81a5144879c24050438e4edb
GIT binary patch
literal 7112
zcmeHKYgCfy7UmNLR20%O%oIp%NVCWs?;2=h;-yTKF|7nIsHNhV8B?hrf|}jbQZqXh
zj#^$PH8r~_m|5v`cNi}@LUuchmNs565f03$wL0hD`E}-pd#%0RXYaM&=Uv~o-uGF1
z2U5Je1SSv&nMT3+QK&&k00N1PN{(lw#>F~9AP{(yD)HIS+7O7wXZ$65UlptUzfH|0
zP$l=JB*&}#FRs+MsC^+c%I2?Y)jTTNzf8>?rTaPfyxdo@tM)Sqs#xt`&I2Gwh?<Ko
z{m*)Jl$w;B^z|WX{xAC=BnasXR-gR^e_7T0zc%%ESf~<|tzO$GRIeb63j2ST7|Du?
zPR2z=r`k|yTWykU?Vaq15TD?!zIFN#NSGVWKOmm*qpD)h{=~hwC`Jkck8|6#m|y%4
zi}zviT`cOrq7E$Tz@iQ;>cFB7Eb73b4lL@xq7MAObU;1dmZ)a#1XgMskr);E@A(^O
zn1(=r7S-Uao{<3@BAW;K24jo6UyfCUO(Cgqn~6j_dlha)3nSqhS)&OZCt4NuL$aa2
z1(Y;|a|NU~7F>NEpHAfplm{fg-NW4ldw?70W={#-O1QL<G)Dj(f-0PCtW2r^BnB%W
zEfMmvITF4J0t-uOMuSq4qmEs<*fpG5lfaW6GyKEn^w|4YV(!A@PerjyF2wX1jTw<9
zl7dzA=_nJWw<DS}nlTBpfj<OuX2|AjfZvbOQnY>ADGIcPY22BJxRPT6)(63ooCIro
zgN#P=nPfyd3I#bDpkoLXDo&xW8VJ{nPvW@=1MWGgo>)+ZzzHxe(A-j3WTykK&Aesi
zoebJ;VXqULpRvi>+1dMYr+y7o$4mMxIRF6z+wg#JB{Wbt!Q1t5dVhM%(nHW<WzC96
z;mt$YfS)TI%xv~#Ia_j`y&UInw`JwADT%GF=k=C~ZIs2*7p9Hl2JkfSD6%Xpj6Rac
zDtxOQWDE;%g}-0JAzAV)%7ts&d}CJZXg#$6&R%np|DNOi;)P-zc{0p-DW?Gg1w4?C
zfTlOMO7;%{H#W6gayWBt8RcTah2%$XjEp)T%kO>cr@#y#j>fx_t^pi0hCHqC*Q*Li
z3-L6_srPZl=J8UyD)==qF0fDKlUtLD$QSD~<z^aiA_L<AGvjL1VaPNWI;O#x1nPDF
zdWe5ir|H>KtySq0dhA9I-a!XVe)RH+D0Y$Kq&tDOv%c`?q~E~t8b$MqvG>6yYj#7x
z9qJo_G)K_y2<X9Fgw;Jit`V1j2HFNYCYAuS&`?~3|07O^5h3uHm*9-T9n#khGtE3=
zLYkPDHn#Tf4U{r0+Fa{i%=XcV7@DhZnP9o5*EBhdi#GKY(}S2<5>Vgr38SANtiodL
zYQy4+8`q!Kwv@bL#>|!?&8*BUo`_vEy;{gr?kRDm4vq)!RUlV6R5#iNif68FRJ_+{
z3~kPL((i)(K&C3}?>ztNEy;&ivvGDq{?_w;8|6)J2jgxnobBk{7(=hm%BPcHSTH$4
zE-GJJL90r4-zFFt!p>+-uj2Di0Q4PkK3HkK=TA4^S)+K$5~b7eZGHaCp$jnmWy}RH
zd9xNbAI}wJtVZre4~%eumI&%Dl%ckX@9i<NZYV7LwM~-^0g30L+L12nuqY09f^mnk
zOqvFRLN23Il6Ji2EL)ZNAbllw2``_GSx1(12;oP;I;_irQd}EXq;UjgSt)@xZX3W}
zGPSGNRA0#oX1g|;9lqKh%0}}$Lx=@peHhK%OamcHBQ9(9H2daafs1*Cw1xp6nnOpl
z7=L*3$}PZ1T!#WQdr|}-JO{_CZmt<fY%1+4Z?8?L{^y1|s1Dc-<%$lF6J}8PJa?E4
zx{LE0Tkq+>4+s1;tTHw{IebMST#dwo2`~eoWVX}b((RAGk`X?=U>!x&!7N6UXZf`6
zu+yos3H&}g7;7n;NZ;uetDASap@{!|O`=1l?B#RuPcSV4p>PeV_w-}h;OwjQ2B#!D
z3o(wg?&(8W$7P5bnYI!xFopRb>q9$~6X?yY`*{yasIf~Kb@_y4oKKbr5Bn(!LL;zF
zAg2U%WgWy;#*`qnCCCmyOs^Np%${ZgGgR$(?;|cNtwhEPCMVi@Aw)N*Cea;P0u_=?
z48+qNi4EtsAKVK_a7*Id7#Fchf9L&?Pq9CFk6#?0U$dpTk-tG|%G{cGWivH|{%#@}
zdEY)0VX74%ZUN<b(3Esj{Vh6dWKdPx%`(9-RVPU6G7pdOfoFre%r%7f@frkTEYe7M
z{8_DxXbJ@%baC(-nA@8AL03c^XGd1O@+O%R(x3nM9nrAw;xNq7*87S;U<N0j&RylP
z->E&iO!F}QvKF)0;ix@SNLu$K|DKp=*mdCr0F>ZP4!{UOYxOjU)8O~bHeX$A75p=y
zV|e7_nY@kC@g8hmPWAP>qMsT07$`Xh<R-s)=|{U4UHoWA#Jji4^XARCg7m?DELIbb
zqaZvR*Zz3)n4;>IG5KK1`L1?uUK2KB>6^5`<AL@fau&T8&QXjRhq$hniOb-*$|zs>
zLuFsSEuY21(aD<Yd3a>gNhw{n#f)WJdm5YwpQ^B+nn!;Z-6MR7)0H(_fNWPyL;i}h
z=bz{&1f1OU<WCcp0qP^J)G6Sc6gV;JSb@;pRNVbqYz8k~D6Kh@SJZTuMUSr#6o3(8
zros}CAaPS32G4#xZ@T=jrzyfyROf?DBfZgoZV}T%yf%N<H%*heX-B^8sHA_&Cra<+
zvFCYb!TW(5>oT%${&AkiBXvSve$d7p#%uczcjrWSPoyo(>h60GICo+sHJ*BU+T$O#
zx=)d28aheN-Gk_yNXd}*hR}kK$(*ZJReNwU%yxw#S-k0l);ev^N4Dm<&`UpU28SPe
zXSL4WY^W5UgoB(JYZzpLvG#h?Yrg~S9Z{+7>!i_f9ap99wSzw=yzTpz^E(sKAq#Ow
z3y~&wlQ4A@bdHz?>+!>yW{^Qg%=P?ieC?xAKTeg~w%`q~a!p2dt+Z0ij(zBZXWjax
zQ}96&Go?>tBP{k4T;Y?dCzL>(t6aXFxU=qdKymevTtk2BcKH;FXq+rEZlBzqEp}c0
z30EHEzI7M5U?HHeB&~k3b)R&AMFXp5o8F&Yc|@FvfTW~UhZMq}Yhrn;_xJ_7i^3|$
z?dmVdZiQc$Q^#S3N}J3VC@38c6_951Dqo_p(VTZ=)5pYTsawV@ur)VV{JF>N10f;X
zGt1@1^R)mPjl`G>$XaL*=xZg`npTiKZNJ)Qr<sVEF)W~2(@w$h{oo^lRYrIJ!3>iG
zdBU~H){*X^480uC5y3z%rKGz-ACUbnN?YvZB)=<l8KDbzwFhIMt+x-BQ38mSCo(ou
zYh^HQtm@N7r_H(ztW=$VIN}Q2g<nt88P+H25=9!r{)GkOaxelDUHEXW$bW%q6F*`v
z5}ljra*|v35VXztY}BwYr~H=-ebt)Rmq6E09N4~7g9RPgH*ZAK=RWExP{1ddZQAA%
zXsPAo4;f_PyASX6R$+*Et|fHbzT_5Ou{y@#VU6E&ZMXV#!hCp5X}5B`m-$A?937g|
zCl2j77Z-*VosE<Y>CGpmU0PtyEBf0L<IkPb&M6nLQ6oZL<J75KckC;YoA;d*=Hte!
zgPH@jcRKD{!#N8n#+w`wAZA4-Zo%6%TrLGN`7Dr4B*SEcj}4Z&&WIx8<oK?h>TgDO
ziWuh3HY`bY{E<NA*fJppiAhC7-??H}bLOtUH8zi0RS-RuA1v=Auhh@e<XAc-&6)3J
zltB*nB+>r4_s}nb$x8z>P{3`r2?9O~pZ!~Pod073oT2WuRlT&zfY$AT%gWC-#!~)~
j_$5#(6_B_n_6D4)N?ngut(q!V_vq?a1tCc)tmgR_^3}2i

literal 0
HcmV?d00001

-- 
1.5.6.2

